==> apache-parquet-1.13.1.tar.gz: apache-parquet-1.13.1/parquet-cli/src/test/java/org/apache/parquet/cli/commands/ConvertCSVCommandTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.parquet.cli.commands;

import org.apache.hadoop.conf.Configuration;
import org.junit.Assert;
import org.junit.Test;

import java.io.File;
import java.io.IOException;
import java.util.Arrays;

public class ConvertCSVCommandTest extends CSVFileTest {
  @Test
  public void testConvertCSVCommand() throws IOException {
    File file = csvFile();
    ConvertCSVCommand command = new ConvertCSVCommand(createLogger());
    command.targets = Arrays.asList(file.getAbsolutePath());
    File output = new File(getTempFolder(), getClass().getSimpleName() + ".parquet");
    command.outputPath = output.getAbsolutePath();
    command.setConf(new Configuration());
    Assert.assertEquals(0, command.run());
    Assert.assertTrue(output.exists());
  }
}

==> apache-parquet-1.15.2.tar.gz: apache-parquet-1.15.2/parquet-cli/src/test/java/org/apache/parquet/cli/commands/ConvertCSVCommandTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.parquet.cli.commands;

import java.io.File;
import java.io.IOException;
import java.util.Arrays;
import org.apache.hadoop.conf.Configuration;
import org.junit.Assert;
import org.junit.Test;

public class ConvertCSVCommandTest extends CSVFileTest {
  @Test
  public void testConvertCSVCommand() throws IOException {
    File file = csvFile();
    ConvertCSVCommand command = new ConvertCSVCommand(createLogger());
    command.targets = Arrays.asList(file.getAbsolutePath());
    File output = new File(getTempFolder(), getClass().getSimpleName() + ".parquet");
    command.outputPath = output.getAbsolutePath();
    command.setConf(new Configuration());
    Assert.assertEquals(0, command.run());
    Assert.assertTrue(output.exists());
  }

  @Test
  public void testConvertCSVCommandWithMultipleInput() throws IOException {
    File file = csvFile();
    ConvertCSVCommand command = new ConvertCSVCommand(createLogger());
    command.targets = Arrays.asList(file.getAbsolutePath(), file.getAbsolutePath());
    File output = new File(getTempFolder(), getClass().getSimpleName() + ".parquet");
    command.outputPath = output.getAbsolutePath();
    command.setConf(new Configuration());
    Assert.assertEquals(0, command.run());
    Assert.assertTrue(output.exists());
  }

  @Test(expected = IllegalArgumentException.class)
  public void testConvertCSVCommandWithDifferentSchemas() throws IOException {
    File file = csvFile();
    File fileWithDifferentSchema = csvFileWithDifferentSchema();
    ConvertCSVCommand command = new ConvertCSVCommand(createLogger());
    command.targets = Arrays.asList(file.getAbsolutePath(), fileWithDifferentSchema.getAbsolutePath());
    File output = new File(getTempFolder(), getClass().getSimpleName() + ".parquet");
    command.outputPath = output.getAbsolutePath();
    command.setConf(new Configuration());
    command.run();
  }
}
